// --------------------------------------------------------------------------------
// Globals
// --------------------------------------------------------------------------------

var gPreferences = new Object();

// --------------------------------------------------------------------------------
//! Save a locally cached preference to a system preference.
// --------------------------------------------------------------------------------

function savePreference(name)
{
	var value = gPreferences[name];
	var instanceName = widget.identifier + "-" + name;
	widget.setPreferenceForKey(value, instanceName);
	widget.setPreferenceForKey(value, name);
}

// --------------------------------------------------------------------------------
//! Save a locally cached preference to a system preference.
// --------------------------------------------------------------------------------

function saveDictionaryPreference(name)
{
	var items = gPreferences[name];
	
	var values = new Array;
	for (var item in items)
	{
		values.push(item);
		values.push(items[item]);
	}
	
	var value = values.join(",");
		
	var instanceName = widget.identifier + "-" + name;
	widget.setPreferenceForKey(value, instanceName);
	widget.setPreferenceForKey(value, name);
}

// --------------------------------------------------------------------------------
//! Load a system preference into the local cache.
// --------------------------------------------------------------------------------

function loadPreference(name, defaultValue)
{
	var instanceName = widget.identifier + "-" + name;
	var value = widget.preferenceForKey(instanceName);
	if (!value)
		value = widget.preferenceForKey(name);
	if (!value)
		value = defaultValue;
		
	return value;
}

// --------------------------------------------------------------------------------
//! Load a system preference into the local cache.
// --------------------------------------------------------------------------------

function loadDictionaryPreference(name, defaultValue)
{
	var instanceName = widget.identifier + "-" + name;
	var value = widget.preferenceForKey(instanceName);
	if (!value)
		value = widget.preferenceForKey(name);
		
	var items = [];
	if (value)
	{
		var value_list = value.split(",");
		var count = value_list.length;
		for (var i = 0; i < count; i += 2)
			items[value_list[i]] = value_list[i+1];
	}
	else
	{
		items = defaultValue;
	}
	
	return items;
}

// --------------------------------------------------------------------------------
//! Use the value of a locally cached preference to set the value of a field. 
// --------------------------------------------------------------------------------

function updateFieldFromPreference(name)
{
	var field = document.getElementById(name);
	if (field)
		field.value = gPreferences[name];
}

// --------------------------------------------------------------------------------
//! Use the value of a locally cached preference to set the checked state of a button. 
// --------------------------------------------------------------------------------

function updateCheckedFromPreference(name)
{
	var field = document.getElementById(name);
	if (field)
		field.checked = gPreferences[name];
}

// --------------------------------------------------------------------------------
//! Use the value of locally cached preferences to set the selection and items of 
//! a popup.
// --------------------------------------------------------------------------------

function updatePopupFromPreference(popupName, itemsName)
{
	var field = document.getElementById(popupName);
	if (field)
	{
		var items = gPreferences[itemsName];
		var count = items.length;
		var index = 0;
		for (item in items)
		{
			var option = new Option(items[item]);
			option.value = item;
			field.options[index++] = option;
		}

		field.value = gPreferences[popupName];
	}
}



// --------------------------------------------------------------------------------
//! Read the value of a document field and store it in the local preference cache.
// --------------------------------------------------------------------------------

function updatePreferenceFromField(name)
{
	var field = document.getElementById(name);
	if (field)
		gPreferences[name] = field.value;
}

// --------------------------------------------------------------------------------
//! Read the checked state of a document button and store it in the local preference cache.
// --------------------------------------------------------------------------------

function updatePreferenceFromChecked(name)
{
	var field = document.getElementById(name);
	if (field)
		gPreferences[name] = field.checked;
}

// --------------------------------------------------------------------------------
//! Read the value and items of a popup and store them in the local preference cache.
// --------------------------------------------------------------------------------

function updatePreferenceFromPopup(name, itemsName)
{
	var popup = document.getElementById(name);
	if (popup)
	{
		var items = new Object();
		for (var i = 0; i < popup.options.length; i++)
		{
			var option = popup.options[i];
			items[option.value] = option.text;
		}

		gPreferences[name] = popup.value;
		gPreferences[itemsName] = items;
	}
}



